/***************************************************************************
 *   Copyright (C) 2004-2005 by Andrew Krause                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "build.h"

Glib::ustring get_configure_parameters();

// Run the autogen.sh command if a project is currently open.
void OpenLDev::on_autogen()
{  
  if (project->get_name().empty())
    error("Please open or create\na project first!");
  else 
  {
    output->set_current_page(0);
    chdir (project->get_location().c_str());
    
    Glib::ustring command = string(ptemplate->get_autogen()) + " 2>&1";
    output->get_build()->run_command(command, output->get_build_box(), env);
  }
}

// Compile current file if a file and a project is open. The function then
// creates the compile string from the project language & runs the command
void OpenLDev::on_compile() 
{
  if (!noteman->get_file_open())
    error("Please open or create\na file first!");
  else 
  {
    output->set_current_page(0);
    Glib::ustring command = ptemplate->get_compile(noteman->get_current_filename());
    Glib::ustring location = Glib::ustring(project->get_location()) + "src/";
    chdir (project->get_location().c_str());

    command += " 2>&1";
    output->get_build()->run_command(command, output->get_build_box(), env);
  }
}

// If a project is open, build it. Run autogen.sh and then build again if
// Makefiles are not found. All of the files are first saved.
void OpenLDev::on_build() 
{
  if (project->get_name().empty())
    error("Please open or create\na project first!");
  else 
  {
    output->set_current_page(0);
    noteman->save_all_files();
    chdir (project->get_location().c_str());
    
    Glib::ustring command = string(ptemplate->get_build()) + " 2>&1";
    if (!output->get_build()->run_command(command, output->get_build_box(), env))
    {
      on_autogen();
      output->get_build()->run_command(command, output->get_build_box(), env);
    }
  }
}

// If a project is open, run the executable in the terminal specified
// by the user 
void OpenLDev::on_execute() 
{
  if (project->get_name().empty())
    error("Please open or create\na project first!");
  else 
  {
    Glib::ustring command = Glib::ustring(project->get_location())
      + "src/" + project->get_name() + "\n";
    output->set_current_page(2);
    output->run_terminal_command(command);
  }
}

// If a project is open, run the ./configure command in the project directory
void OpenLDev::on_configure() 
{
  if (project->get_name().empty())
    error("Please open or create\na project first!");
  else 
  {
    Glib::ustring parameters = get_configure_parameters();
    if (parameters != "CANCEL")
    {
      output->set_current_page(0);
      chdir (project->get_location().c_str());
    
      Glib::ustring command = string(ptemplate->get_configure()) + " " + parameters + " 2>&1";
      output->get_build()->run_command(command, output->get_build_box(), env);
    }
  }
}

// Clean all of the sources, build files, object files and those files
// created by configure
void OpenLDev::on_clean()
{
  if (project->get_name().empty())
    error("Please open or create\na project first!");
  else 
  {
    output->set_current_page(0);
    chdir (project->get_location().c_str());
    
    Glib::ustring command = string(ptemplate->get_clean()) + " 2>&1";
    output->get_build()->run_command(command, output->get_build_box(), env);
  }
}

// Stop the current compilation, clean, configure, autogen or build
void OpenLDev::on_stop() 
{ output->get_build()->stop_build();
}

// Create a dialog that will ask the user for parameters to send to the
// ./configure command. It returns the parameters even if they are empty.
// The string "CANCEL" is returned if the user chooses to Cancel.
Glib::ustring get_configure_parameters()
{
  Glib::ustring return_text;
  Gtk::Dialog *configure_dialog = new Gtk::Dialog();
  Gtk::Button *cancel = new Gtk::Button(Gtk::StockID("gtk-cancel"));
  Gtk::Button *ok = new Gtk::Button(Gtk::StockID("gtk-ok"));
  Gtk::Label *label = new Gtk::Label("Parameters:");
  Gtk::Entry *parameters = new Gtk::Entry();
  Gtk::HBox *hbox = new Gtk::HBox(false, 10);
  
  ok->set_flags(Gtk::CAN_DEFAULT);
  hbox->set_spacing(10);
  hbox->pack_start(*label, Gtk::PACK_SHRINK, 0);
  hbox->pack_start(*parameters);
  
  configure_dialog->get_vbox()->pack_start(*hbox);
  configure_dialog->set_border_width(5);
  configure_dialog->set_size_request(350, 100);
  configure_dialog->set_title("Configure Parameters");
  configure_dialog->set_modal(true);
  configure_dialog->set_resizable(false);
  configure_dialog->property_destroy_with_parent().set_value(true);
  configure_dialog->set_has_separator(true);
  configure_dialog->add_action_widget(*cancel, -6);
  configure_dialog->add_action_widget(*ok, -5);
  configure_dialog->show_all_children();

  switch (configure_dialog->run())
  {
    case (Gtk::RESPONSE_OK):
      return_text = parameters->get_text();
      break;
    default:
      return_text = "CANCEL";
      break;
  }
  
  configure_dialog->hide();
  return return_text;
}
