/***************************************************************************
 *   Copyright (C) 2004-2005 by Andrew Krause                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "edit.h"

// Update the TextBuffer that is sent to this function. It marks it modified
// when text has been entered and shows the cursor on screen.
void OpenLDev::update_textview(Glib::RefPtr<Gtk::TextBuffer> buffer)
{
  noteman->mark_current_tab_modified(true); 
  noteman->scroll_to_mark();
}

// Cut the currently selected text from the buffer. Then add the text to the
// actionmanager of the current buffer and redo the syntax highlighting
void OpenLDev::on_edit_cut()
{
  Glib::RefPtr<Gtk::Clipboard> Clipboard = Gtk::Clipboard::get();
  Glib::RefPtr<Gtk::TextBuffer> buffer = noteman->get_textbuffer();
  
  buffer->cut_clipboard(Clipboard, true);
  update_textview(buffer);
}

// Cut the currently selected text from the buffer.
void OpenLDev::on_edit_copy()
{
  Glib::RefPtr<Gtk::Clipboard> Clipboard = Gtk::Clipboard::get();
  Glib::RefPtr<Gtk::TextBuffer> buffer = noteman->get_textbuffer();
  buffer->copy_clipboard(Clipboard);
}

// Paste the clipboard text to the current cursor position. Then add the text 
// to the actionmanager of the current buffer and redo the syntax highlighting
void OpenLDev::on_edit_paste()
{
  Glib::RefPtr<Gtk::Clipboard> Clipboard = Gtk::Clipboard::get();
  Glib::RefPtr<Gtk::TextBuffer> buffer = noteman->get_textbuffer();
  
  buffer->paste_clipboard(Clipboard, true);
  update_textview(buffer);
}

// Select all text in the text_view
void OpenLDev::on_edit_selectall() 
{
  Glib::RefPtr<Gtk::TextBuffer> buffer = noteman->get_textbuffer();
  buffer->move_mark(buffer->get_insert(), buffer->begin());
  buffer->move_mark(buffer->get_selection_bound(), buffer->end());
}

// Deselect any text that is selected
void OpenLDev::on_edit_deselect() 
{
  Glib::RefPtr<Gtk::TextBuffer> buffer = noteman->get_textbuffer();
  buffer->move_mark(buffer->get_selection_bound(), buffer->get_insert()->get_iter());
}

// Undo the last action that was performed. If there was no action, then don't
// do anything. To undo a delete, just insert the text. To undo an insert, the
// text must be removed from the specified offset & then backwards the length
void OpenLDev::on_edit_undo() 
{
  if (noteman->get_textbuffer()->can_undo())
    noteman->get_textbuffer()->undo();
}

// Redo the last action that was undone. If there was no action, then don't
// do anything. To redo an insert, you must remove the text from the specified
// offset to backwards the length of the text. To redo a delete, just move
// backward the length of the string & insert it
void OpenLDev::on_edit_redo()  
{
  if (noteman->get_textbuffer()->can_redo())
    noteman->get_textbuffer()->redo();
}
