/***************************************************************************
 *   Copyright (C) 2004-2005 by Andrew Krause                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "outputmanager.h"

OutputManager::OutputManager()
{
  search = new OutputSearch();
  build = new OutputBuild();
  terminal = new OutputTerminal();
  compiler = new Gtk::HBox(false, 0);
  compiler_label = new Gtk::Label("Compiler");
  compiler_image = new Gtk::Image(Gtk::StockID("gtk-execute"), Gtk::IconSize(1));
  findtab = new Gtk::HBox(false, 0);
  findtab_label = new Gtk::Label("Search");
  findtab_image = new Gtk::Image(Gtk::StockID("gtk-find"), Gtk::IconSize(1));
  terminaltab = new Gtk::HBox(false, 0);
  terminaltab_label = new Gtk::Label("Terminal");
  terminaltab_image = new Gtk::Image(Gtk::StockID("gtk-find"), Gtk::IconSize(1));
  
  compiler->set_spacing(5);
  compiler->pack_start(*compiler_image, Gtk::PACK_SHRINK);
  compiler->pack_start(*compiler_label, Gtk::PACK_SHRINK);
  findtab->set_spacing(5);
  findtab->pack_start(*findtab_image, Gtk::PACK_SHRINK);
  findtab->pack_start(*findtab_label, Gtk::PACK_SHRINK);
  terminaltab->set_spacing(5);
  terminaltab->pack_start(*terminaltab_image, Gtk::PACK_SHRINK);
  terminaltab->pack_start(*terminaltab_label, Gtk::PACK_SHRINK);
  
  append_page(*build->get_swin(), *compiler);
  append_page(*search->get_swin(), *findtab);
  append_page(*terminal->get_swin(), *terminaltab);
  
  compiler->show();
  compiler_image->show();
  compiler_label->show();
  findtab->show();
  findtab_image->show();
  findtab_label->show();
  terminaltab->show();
  terminaltab_image->show();
  terminaltab_label->show();
  set_current_page(1);
}

void OutputManager::run_terminal_command(Glib::ustring command)
{ 
  terminal->run_command(command);
  grab_terminal_focus();
}

void OutputManager::grab_terminal_focus()
{ terminal->grab_focus();
}

Gtk::TreeView* OutputManager::get_build_box()
{ return build->get_build_box();
}

Gtk::TreeView* OutputManager::get_search_box()
{ return search->get_search_box();
}

Gtk::ScrolledWindow* OutputManager::get_build_swin()
{ return build->get_swin();
}

Gtk::ScrolledWindow* OutputManager::get_search_swin()
{ return search->get_swin();
}

OutputBuild* OutputManager::get_build()
{ return build;
}
